clear all 
clc
% This script calculates the loss when one of the inputs are constrained
% The constrained input must be specified by user-promt.
% Objective
%min(J) = (1/2)*u1^2 + (1/2)(u2-d2)^2
%s.t. u1-d1-1 >= 0
dnom = [0 0];

Q = [0.5 0;
     0 0.5];
A = [1 0]; % Define constraint
c = [0 -dnom(2)];
b = (1+dnom(1)); % Define constraint
clear model;
names = {'u1', 'u2'};
model.varnames = names;
model.Q = sparse(Q);
model.A = sparse(A);
model.obj = c;
model.rhs = b;
model.sense = ['>'];
model.objcon = dnom(2)^2;
gurobi_write(model, 'qp.lp');

results = gurobi(model); % Calculate nominal point
lambda = results.pi; % Calculate lagrange multiplier of constraint
%%
nu = 2;
ny = 4;% y = [u1 u2 d1 d2]
nd = 2;
nc = 1; % number of constraints
%fprintf('Which u is constrained, enter value less or equal to %d:',nu);
%consu = input('');
consu = 1; % Which u is constrained?
% Reduced J= 0.5*(u2^2-2*u2*d2+d2^2) + 1

Gy = [1 0;
      0 1;
      0.1 2;
      2 3];
Gyd = [0 0;
       0 0;
       1 0.2;
       0.5 3];
%Juu = [0 0; 0 1];
Juu = 1;
Juu12 = Juu^(1/2);
Jud = [0 -1]; %d1 d2

Gyd(:,1) = (-Gy(:,consu)+Gyd(:,1));
Gy(:,consu) = [];
F = (-Gy/Juu)*Jud+Gyd;

Wd =  [0.5 1]';
Wn1vec = [0.1 0.1 0.1 0.1];
Wn2vec = [1 1 1 1];
Wn1 = diag(Wn1vec);
Wn2 = diag(Wn2vec);
Y1 = [F*Wd Wn1];
Y2 = [F*Wd Wn2];
Y = [Y1;Y2];
Ydel1=Y1;
Ydel2=Y2;
Fdel1=Ydel1*Ydel1';
Fdel2=Ydel2*Ydel2';
Fdel = blkdiag(Fdel1,Fdel2);

Gydel=[];
for i=1:nu-nc %unconstrained u???
    Gydel=blkdiag(Gydel,Gy);
end
size(Gydel)
Gydel = [Gydel;Gydel];% Wn1 Wn2
Gy1 = [Gy;Gy];
%
jdel=[];
for i=1:nu-nc % Unconstrained
    jdel=[jdel ; Juu12];
end


M=500; % Big-M
%Define empty matrices
price = zeros(length(nu-nc:ny),1); % price of measurements
loss = zeros(length(nu-nc:ny),1); % Unconstrained loss
closs = zeros(length(nu-nc:ny),1); % Constrained loss
cost = zeros(length(nu-nc:ny),1); % price+loss+closs
ltot =zeros(length(nu-nc:ny),1); % Total loss 
Hres=zeros((nu-nc),2*ny,length(nu-nc:ny));
Meas=zeros(1,2*ny,length(nu-nc:ny));
cmeas=zeros(1,2,length(nu-nc:ny)); % Selected constrained measurement
%% Unconstrained Two Set of Measurements
mprices = [0.2*ones(1,ny) 0.02*ones(1,ny)]; % Prices of each measurement 
cprices = [0.2 0.02]; % Prices of constrained measurement
% Link up so that if one measurement set is selected, the corresponding
% value in Selection matrix for the same measurement in the other set
% Is set to zero
subM = zeros(ny*(nu-nc)*2,ny*2); 
for i=1:ny
        subM(i,i+ny) = 1; % u2w1 <-> w2
        subM(i+ny,i)=1; % u2w2 <-> w1
       % subM(i+2*ny,i) = 1;
        %subM(i+3*ny,i) = 1;
end
% Constrained big-M 
consumat = eye(ny*(nu-nc)); 
sigma1Mconstr = -M*([consumat*repmat(eye(ny),nu-1,1);zeros(ny,ny)]);
sigma2Mconstr = -M*([zeros(ny,ny);consumat*repmat(eye(ny),nu-1,1)]);

for nm = (nu-nc):ny

    Q=blkdiag(Fdel,zeros(ny,ny),zeros(ny,ny),0,zeros(4,4)); %Last two is for u1
        %H                  sigma_w1             sigma_w2              %nm
    A= [Gydel'            zeros((nu-nc)*(nu-nc),ny)    zeros((nu-nc)*(nu-nc),ny)      zeros((nu-nc)*(nu-nc),1) zeros(1,4) ;
        zeros(1,(nu-nc)*ny*2)  ones(1,ny)           ones(1,ny)       -1              zeros(1,4);
       -blkdiag(eye((nu-nc)*ny),eye((nu-nc)*ny))     sigma1Mconstr      sigma2Mconstr  zeros((nu-nc)*ny*2,1) zeros((nu-nc)*ny*2,4) ;
        blkdiag(eye((nu-nc)*ny),eye((nu-nc)*ny))     sigma1Mconstr      sigma2Mconstr  zeros((nu-nc)*ny*2,1) zeros((nu-nc)*ny*2,4);
        zeros(1,(nu-nc)*ny*2)  zeros(1,ny)   zeros(1,ny)               1   zeros(1,4) ;
        eye((nu-nc)*ny*2)      M*subM          zeros(ny*(nu-nc)*2,1) zeros((nu-nc)*ny*2,4);
       -eye((nu-nc)*ny*2)      M*subM          zeros(ny*(nu-nc)*2,1) zeros((nu-nc)*ny*2,4);
       zeros(1,(nu-nc)*ny*2+2*ny+1) 0 0 1 1; % Force to select only one of these
       zeros(1,(nu-nc)*ny*2+2*ny+1) 1 1 0 0; % Force to select only one of these
       ];
                                                    % sigma_cons
    c = [zeros(1,(nu-nc)*ny*2) mprices       0     cprices(1) cprices(2) 0 0];
    c(end-1) = lambda*Wn1vec(1);
    c(end) = lambda*Wn2vec(1);
    lb=[-inf((nu-nc)*ny*2,1);  zeros(ny,1); zeros(ny,1)  ;0;0;0  ; -inf ;-inf];
    ub=[inf((nu-nc)*ny*2,1);   ones(ny,1) ; ones(ny,1)  ;ny;1;1 ;inf;inf];

    b= [jdel; 
        0
        zeros(2*(nu-nc)*ny,1);
        zeros(2*(nu-nc)*ny,1)
        nm
        M*ones(2*(nu-nc)*ny,1)
        M*ones(2*(nu-nc)*ny,1)
        1
        1
      ];

    %try
        clear model;
        names = {...%'H_y1u1w1', 'H_y2u1w1', 'H_y3u1w1','H_y4u1w1', ...
                 'H_y1u2w1', 'H_y2u2w1', 'H_y3u2w1','H_y4u2w1',...
                 ...%'H_y1u1w2', 'H_y2u1w2', 'H_y3u1w2','H_y4u1w2',...
                 'H_y1u2w2', 'H_y2u2w2', 'H_y3u2w2','H_y4u2w2',...
                 '$y_1w_1$', '$y_2w_1$', '$y_3w_1$', '$y_4w_1$',...
                 '$y_1w_2$', '$y_2w_2$', '$y_3w_2$', '$y_4w_2$',...
                 'nm'...
                 '$y_5w_1$','$y_5w_2$','H_y5u1w1','H_y5u1w2'};
        model.varnames = names;

         
        model.sos(1).type =1;
        model.sos(1).index=[(4*ny+3) (4*ny+4)];
        model.sos(1).weight=[1 1];
        model.Q = sparse(Q);
        model.A = sparse(A);
        model.obj = c;
        model.rhs = b;
        model.lb = lb;
        model.ub = ub;
        model.sense = [repmat('=',(nu-nc)*(nu-nc)+1,1);repmat('<',2*(nu-nc)*ny,1);...
            repmat('<',2*(nu-nc)*ny,1);'=';repmat('<',2*(nu-nc)*ny,1);...
            repmat('<',2*(nu-nc)*ny,1);'=';'='];
        model.modelsense='min'
        model.vtype = [repmat('C',2*(nu-nc)*ny,1);repmat('B',2*ny,1);'I';...
                        repmat('B',2,1);repmat('B',2,1)];
        gurobi_write(model, 'qp2.lp');
        params.Presolve = -1
        params.FeasibilityTol=1e-9
        params.OptimalityTol=1e-9
        results = gurobi(model, params) 
 % Fill in results
    Hres(:,:,nm-(nu-nc)+1) = [results.x(1:2*ny)'];
    H = Hres(:,:,nm-(nu-nc)+1);
    Meas(:,:,nm-(nu-nc)+1) = [results.x(2*ny+1:4*ny)'];
    cmeas(:,:,nm-(nu-nc)+1) = [results.x(end-3:end-2)'];
    loss(nm-(nu-nc)+1)= (results.x'*Q*results.x)/2;%+model.obj*results.x;
    loss1= 0.5*norm(Juu12/(H*Gy1)*H*Y,'fro')^2; %unconstrained loss
    % Make sure that loss is calculated correctly in optimizer vs. 
    % Exact local method
    if loss(nm-(nu-nc)+1)-loss1 > 1e-3
        disp('Error in unconstrained loss calculation')
        break
    end
    % Constrained Loss, H(1) is constrained
    closs(nm-(nu-nc)+1) = c(end-1:end)*results.x(end-1:end);
    price(nm-(nu-nc)+1) = c(1:end-2)*results.x(1:end-2);
    ltot(nm-(nu-nc)+1) = loss(nm-(nu-nc)+1) + closs(nm-(nu-nc)+1);
    cost(nm-(nu-nc)+1) = loss(nm-(nu-nc)+1)+closs(nm-(nu-nc)+1)...
                        +price(nm-(nu-nc)+1);
end

    