function [Vo_LPO,Vo_HPO,qen]=DeWaterer(qin,Vo_in,FS,rin,p3)

Ro=p3(2);Ri=p3(3);

qi=FS*qin;      %Light phase out flow
qo=qin-qi;      %Heavy phase out flow

% Volume fractio of water in outlets before
% the re-entrainment is accounted for
% eq:3.21
Vw_HPO=(1-Vo_in)*(((1-FS)*Ri^2+FS*(Ri^2-rin^2))/((1-FS)*Ri^2));
% eq:3:22
Vw_LPO=((1-Vo_in)*qin-Vw_HPO*qo)/qi;
% Re-entrainment definitions
u_LPO=qi/(pi*Ri^2); % Area averaged velocity
u_HPO=qo/(pi*(Ro^2-Ri^2)); % Area averaged velocity
du=u_LPO-u_HPO;
k=2*10^-4;
qen=k*du;

%Re-Entrainment
if du>=0 % Velocity in oil > Velocity in water
    Vw_LPO=(Vw_LPO*(qi-qen)+Vw_HPO*qen)/qi;
    Vw_HPO=((1-Vo_in)*qin-Vw_LPO*qi)/qo;
else
    Vw_HPO=(Vw_HPO*(qi+qen)-Vw_LPO*qen)/qi;
end

% Restrict water volume fraction in HPO 
% to range Vw_in->1
if Vw_HPO>1
    Vw_HPO=1;
elseif Vw_HPO<(1-Vo_in)
    Vw_HPO=(1-Vo_in);
end

Vw_LPO=((1-Vo_in)*qin-Vw_HPO*qo)/qi;

Vo_LPO=1-Vw_LPO;
Vo_HPO=1-Vw_HPO;
end