% This scrip is divided into subsections, so the whole scripts
% should not be run at once
%% Estimate Vo_LPO and Vo_HPO vs. Vo_in
clear all
Vo_in=[0.1:0.025:0.6];  % Inlet oil cut
qin=[10,20,30]/3600;    % Inlet flow rate

Vo_HPO=zeros(length(qin),length(Vo_in));    % HPO oil cut
Vo_LPO=zeros(length(qin),length(Vo_in));    % LPO oil cut
Edil=zeros(length(qin),length(Vo_in));      % Dilute efficiency
Edis=zeros(length(qin),length(Vo_in));      % Dispersed efficiency
FS=zeros(size(qin));
 
element='l';
for j=1:length(qin)
    for i=1:length(Vo_in)
        FS(i)=Vo_in(i);
        [Vo_LPO(j,i),Vo_HPO(j,i),Edil(j,i),Edis(j,i),qen(j,i)]...
            =swirl_func3(Vo_in(i),qin(j),FS(i),element);
    end
end

Vo_HPO;
Vo_LPO;
Edil;
Edis;
%% Plot Vo_LPO and Vo_HPO vs. Vo_in (fig. 7.9 van Campen)
%Calculated
figure(11)
hold on
width=2;
plot(Vo_in,Vo_LPO(1,:),'k','LineWidth',width)
plot(Vo_in,Vo_LPO(2,:),'b','LineWidth',width)
plot(Vo_in,Vo_LPO(3,:),'r','LineWidth',width)
plot(Vo_in,Vo_in,'--k','LineWidth',width)
plot(Vo_in,Vo_HPO(1,:),'k','LineWidth',width)
plot(Vo_in,Vo_HPO(2,:),'b','LineWidth',width)
plot(Vo_in,Vo_HPO(3,:),'r','LineWidth',width)
% Experimental
Vo_ine=0.1:0.1:0.6;
%ocl10l=[0.82,0.82,0.82,0.82,0.78,0.63];
ocl10l=[0.84,0.85,0.87,0.85,0.78,0.65];
och10l=(Vo_ine.*(1-ocl10l))./(1-Vo_ine);
%och10l=[0.06,0.02,0.04,0.11,0.19,0.51];
ocl20l=[0.26,0.53,0.62,0.64,0.68,0.61];
och20l=(Vo_ine.*(1-ocl20l))./(1-Vo_ine);
%och20l=[0.08,0.12,0.16,0.22,0.34,0.54];
ocl30l=[0.19,0.42,0.51,0.54,0.58,0.62];
och30l=(Vo_ine.*(1-ocl30l))./(1-Vo_ine);
%och30l=[0.08,0.14,0.21,0.29,0.42,0.57];
%plot(Vo_ine,Vo_ine,'--b')
size=4;
plot(Vo_ine,ocl10l,'kd',Vo_ine,och10l,'kd','markers',size,'MarkerFaceColor','k')
plot(Vo_ine,ocl20l,'bd',Vo_ine,och20l,'bd','markers',size,'MarkerFaceColor','b')
plot(Vo_ine,ocl30l,'rd',Vo_ine,och30l,'rd','markers',size,'MarkerFaceColor','r')

%title('Figure 7.9, 10 (k),20 (b) & 30 (r) m^3/h')
legend('10 $m^3/h$','20 $m^3/h$','30 $m^3/h$')
ylabel('$\alpha_{LPO}$, $\alpha_{HPO}$ [-]')
xlabel('$\alpha_{in}$ [-]')
hold off

%% Estimate efficiency vs. FS
clear all

FS=0.1:0.025:0.6;
%FS = 0.3;
Vo_in=[0.15,0.25,0.4];%[0.01:0.025:0.6];
%Vo_in = 0.3;
%qin = [5:0.5:50]/3600;
qin=56.5/3600;%[25:5:60]/3600;%

Vo_HPO=zeros(length(FS),length(Vo_in));
Vo_LPO=zeros(length(FS),length(Vo_in));
Edil=zeros(length(FS),length(Vo_in));
Edis=zeros(length(FS),length(Vo_in));

element='s';
    for j=1:length(FS)
        for i=1:length(Vo_in)
            [Vo_LPO(j,i),Vo_HPO(j,i),Edil(j,i),Edis(j,i),qen(j,i)]...
            =swirl_func3(Vo_in(i),qin,FS(j),element);

        end
    end

% for k = 1:length(qin)
%     for j=1:length(FS)
%         for i=1:length(Vo_in)
%             [Vo_LPO(k),Vo_HPO(k),Edil(k),Edis(k),qen(k)]...
%             =swirl_func3(Vo_in(i),qin(k),FS(j),element);
% 
%         end
%     end
% end
%% Plot Vo_LPO & HPO vs FS (fig 5.6 in Tyvold thesis)
h1=figure(1);plot(FS,Vo_LPO,'LineWidth',2);
xlabel('FS [-]');ylabel('$\alpha_{LPO}$ [-]')
h2=figure(2);hold on
plot(FS,Vo_HPO,'Color',h2.CurrentAxes.ColorOrder(5,:),'LineWidth',2); %
xlabel('FS [-]');ylabel('$(1-\alpha_{HPO})$ [-]')
%% Plot efficiency vs. FS (fig 7.6 in van Campen thesis)
FSe=0.2:0.1:0.6;
ex_dil15=[0.58,0.67,0.75,0.83,0.9];
ex_dil25=[0.45,0.55,0.65,0.72,0.8];
ex_dil40=[0.35,0.45,0.55,0.65,0.75];
ex_dil=[ex_dil15;ex_dil25;ex_dil40]';
ex_dis15=[0.82,0.76,0.68,0.62,0.5];
ex_dis25=[0.78,0.74,0.68,0.63,0.55];
ex_dis40=[0.68,0.68,0.67,0.65,0.63];
ex_dis=[ex_dis15;ex_dis25;ex_dis40]';

for i=1:length(Vo_in)
    h1=figure(20);hold on;
    h1.CurrentAxes.ColorOrderIndex=i;
    plot(FS,Edil(:,i),'LineWidth',2);
    h2=figure(21);hold on;
    h2.CurrentAxes.ColorOrderIndex=i;
    plot(FS,Edis(:,i),'LineWidth',2)
    legend('$\alpha_{in}=0.15$','$\alpha_{in}=0.25$','$\alpha_{in}=0.40$')
end
% for i=1:length(Vo_in)
%     h1=figure(22);hold on;
%     h1.CurrentAxes.ColorOrderIndex=i;
%     plot(qin*3600,Edil,'LineWidth',2);
%     xlabel('qin [-]')
%     ylabel('$\eta_{dil}$ [-]')
%     h2=figure(23);hold on;
%     h2.CurrentAxes.ColorOrderIndex=i;
%     plot(qin*3600,Edis,'LineWidth',2)
%     legend('$\alpha_{in}=0.3$')
%     xlabel('qin [-]')
%     ylabel('$\eta_{dis}$ [-]')
% 
% end
figure(20);legend('$\alpha_{in}=0.15$','$\alpha_{in}=0.25$','$\alpha_{in}=0.40$')
xlabel('FS [-]')
ylabel('$\eta_{dil}$ [-]')
figure(21);legend('$\alpha_{in}=0.15$','$\alpha_{in}=0.25$','$\alpha_{in}=0.40$')
xlabel('FS [-]')
ylabel('$\eta_{dis}$ [-]')
for i=1:length(Vo_in)
    h1=figure(20);hold on;
    plot(FSe,ex_dil(:,i),'d','MarkerFaceColor',h1.CurrentAxes.ColorOrder(i,:),...
'MarkerEdgeColor',h1.CurrentAxes.ColorOrder(i,:))
    h2=figure(21);hold on;
    plot(FSe,ex_dis(:,i),'d','MarkerFaceColor',h2.CurrentAxes.ColorOrder(i,:),...
'MarkerEdgeColor',h2.CurrentAxes.ColorOrder(i,:))
end

